@@ -1,4 +1,5 @@
 import os
+import platform
 import time
 import requests
 import urllib3
@@ -29,7 +30,7 @@ class Request:
 
     def selenium(self):
         try:
-            if os.name not in ['posix']:
+            if self.is_headless_supported():
                 chrome_options = webdriver.ChromeOptions()
                 chrome_options.add_argument('--no-sandbox')
                 display = Display(visible=0, size=(1024, 768))
@@ -47,7 +48,7 @@ class Request:
             url = driver.current_url
             driver.quit()
 
-            if os.name not in ['posix']:
+            if self.is_headless_supported():
                 display.stop()
 
             return Response(url, 200 if html_data != '' else 204, {}, html_data)
@@ -86,6 +87,11 @@ class Request:
             'User-Agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko)'
         }))
 
+    @staticmethod
+    def is_headless_supported():
+        not_supported = ['darwin']
+        return platform.system().lower() not in not_supported
+
     @staticmethod
     def response(response):
         return Response(
